@@ -2,7 +2,7 @@
 # coding=utf-8
 
 """
-basic types and utils
+defines exception types and constants
 """
 
 import logging
